@@ -313,7 +313,13 @@ class R3sponse(object):
 			# assign attributes.
 			if json != None:
 				if isinstance(json, str):
-					self.assign(pypi_json.loads(Formats.String(json).slice_dict()))
+					try:
+						self.assign(pypi_json.loads(json))
+					except:
+						try:
+							self.assign(ast.literal_eval(json))
+						except:
+							self.assign(pypi_json.loads(Formats.String(json).slice_dict()))
 				elif isinstance(json, dict):
 					self.assign(json)
 				elif json != None:
